* Analytical model for a single silicon electron transistor in a
* stacked nanopillar developed for HSPICE O-2018.09
* The model is described in detail in the article
* F. J. Klüpfel, IEEE Access 7, 84053-84065 (2019),
* DOI: 10.1109/ACCESS.2019.2924913
*
* This file is part of
* Compact Model for a Silicon Single Electron Transistor in a Stacked
* Nanopillar - Implementations in HSPICE and EXCEL/VBA
* Fabian J. Klüpfel and Peter Pichler
* Fraunhofer Institute for Integrated Systems and Device Technology IISB
* January 2021
* DOI: 10.24406/fordatis/116
*
* The research leading to these results has received funding from the
* European Union's Horizon 2020 research and innovation programme
* under grant agreement No. 688072 IONS4SET
*
* +---------------+
* |           _.-´|  F R A U N H O F E R
* |    ___.--´_.-´|
* |---´ __.--´ .-´|  +-+ +-+  .--+ +--.
* |=---´    _-´ ,´|  | | | | /  -+ | ^ \
* |   _.-=-´  -´,´|  | | | | \  \  |   /
* |_-=="¯  ,-´,´  |  | | | |  \  \ |   \
* |="¯ _.-´,-´    |  | | | | +-  / | v /
* | .-´ ,-´       |  +-+ +-+ +--´  +--´
* +---------------+
*
* ----- Update information ------ *
*
* Version 5 (December 2020):
* In version 4, the conduction band edges were taken as a reference
* for the voltages on the contact. This caused a shift in the gate-source
* and drain-source voltages when the source, drain and gate carrier
* densities are not equal. This has been fixed in this version by taking
* the Fermi level energies in the contacts into account.
*
* ----- SET GEOMETRY ----- *
*
* - cylindrical symmetry
* - based on Si nanopillar with embedded oxide layer
* - ring-shaped all-around gate
*
* - cross section of the SET structure:
*
*           |          |
* ------+   |  Source  |   +-------
*       |   +----------+   |      ^
*       |       ____  ^    |      |
*       |      /    \ |    |      |hg
*  Gate |      | QD | |hox | Gate |
*       |      \____/ |    |      |
*       |             v    |      |
*       |   +----------+   |      v
* ------+   |   Drain  |   +-------
*           |          |
*           |<-------->|<->
*               dpil     tgp
*
*
* ----- MODEl DECLARATION ----- *
*
*              DRAIN
*              | GATE
*              | | SOURCE
*              | | |
.SUBCKT   SET  1 2 3
+
+ $ Geometrical parameters
+ TEMP	= 300	$ [K] temperature
+ ddot	= 3.2	$ [nm] quantum dot diameter
+ hox	= 5.6	$ [nm] oxide thickness between source and drain
+ dpil	= 10	$ [nm] silicon pillar diameter
+ tgp	= 3	$ [nm] oxide thickness between gate and pillar
+ hg	= 10	$ [nm] height of all-around-gate
+
+ $ QD properties
+ Qbg	= 0	$ [e] background charge
+
+ $ doping
+ nSrc	= 1.0	$ [1e20 cm-3] source carrier density
+ nDrn	= 1.0	$ [1e20 cm-3] drain carrier density
+ nGte	= 1.0	$ [1e20 cm-3] drain carrier density
+
+ $ Fitting parameters
+ A	= 0.55	$ scaling factor for current
+ cen	= 1.25	$ factor for QD energy levels
+ c0	= 1.2	$ factor for total QD capacitance Cdot0
+ c1	= 0.83	$ factor for total QD capacitance Cdot1
+ cgp	= 2.50	$ [nm] transition between outer and inner capacitance

* ----- CONSTANTS ----- *

.PARAM ec0	= 1.6021892  $ [1e-19 C]
.PARAM kb0	= 1.380662   $ [1e-23 J/K]
.PARAM hbar0	= 1.0545718  $ [1e-34 Js]
.PARAM me0	= 9.10938356 $ [1e-31 kg]
.PARAM eps0	= 8.85418782 $ [1e-12 F/m]
.PARAM pi	= 3.14159265

* ----- MODEL PARAMETERS ----- *

* Material parameters
.PARAM Ebarr	= 3.15	$ [eV] energy barrier between insulator and electrode conduction bands
.PARAM gElec 	= 6	$ degeneracy of electrode conduction band minimum
.PARAM gDot	= 12	$ degeneracy of quantum dot energy states
.PARAM mElec	= 0.328	$ effective electron mass of electrode
.PARAM mDot	= 0.328	$ effective electron mass of quantum dot
.PARAM mBarr	= 0.5	$ effective electron mass of insulator
.PARAM epsBarr	= 3.9	$ relative dielectric constant of barrier material

.PARAM dSrc	= '0.5*(hox-ddot)'	$ [nm] distance between source electrode and quantum dot
.PARAM dDrn	= '0.5*(hox-ddot)'	$ [nm] distance between drain electrode and quantum dot

* ----- CALCULATIONS ----- *

* Derived parameters
.PARAM beta	= '1e4*ec0/(kb0*TEMP)'	$ [1/eV]
.PARAM dSrc	= '0.5*(hox-ddot)'	$ [nm] distance between source electrode and quantum dot
.PARAM dDrn	= '0.5*(hox-ddot)'	$ [nm] distance between drain electrode and quantum dot
.PARAM Nc	= '1e-5*2*gElec*(mElec*me0*kb0*TEMP/(2*pi*hbar0**2))**1.5'	$ [1e20 cm-3]
.PARAM EfSrc	= '1e-4*kb0*TEMP/ec0 * ( log(nSrc/Nc)/(1-nSrc/Nc) + (3*sqrt(pi)*nSrc/Nc/4)**(2/3) \
	+ 8*sqrt(pi)*nSrc/Nc/(3*(4+sqrt(pi)*nSrc/Nc)**2) )'	$ [eV] source fermi level
.PARAM EfDrn	= '1e-4*kb0*TEMP/ec0 * ( log(nDrn/Nc)/(1-nDrn/Nc) + (3*sqrt(pi)*nDrn/Nc/4)**(2/3) \
	+ 8*sqrt(pi)*nDrn/Nc/(3*(4+sqrt(pi)*nDrn/Nc)**2) )'	$ [eV] drain fermi level
.PARAM EfGte	= '1e-4*kb0*TEMP/ec0 * ( log(nGte/Nc)/(1-nGte/Nc) + (3*sqrt(pi)*nGte/Nc/4)**(2/3) \
	+ 8*sqrt(pi)*nGte/Nc/(3*(4+sqrt(pi)*nGte/Nc)**2) )'	$ [eV] gate fermi level
*.PARAM VgOff	= 'EfGte - 0.5*(EfSrc+EfDrn)' $ [V] gate voltage offset
*.PARAM VdOff   = '0' $ [V] drain voltage offset
 .PARAM VgOff	= 'EfGte - EfSrc' $ [V] gate voltage offset
 .PARAM VdOff   = 'EfDrn - EfSrc' $ [V] drain voltage offset

* Current offset (normally 1024/pi**5, here including correction for QD curvature)
.PARAM _currOff	= 'A*16*pi*hox**2*hbar0**2/(2*mBarr*me0*ec0*Ebarr*ddot**4)'

* Capacitances [aF]
.PARAM CdotM = '1e-3 * 4*pi*eps0*epsBarr/(2/ddot-1.5/hox)'
.PARAM Cdot0 = 'c0*CdotM'
.PARAM Cdot1 = 'c1*CdotM'
.PARAM tgp1 = '1/(1/tgp^1.5+1/cgp^1.5)^(2/3)' $ empirical dependency
.PARAM tgp2 = 'tgp - tgp1'
.PARAM CgInner = 'SQRT((dpil+2*tgp1)/ddot)*exp(0.5*pi/hox*(ddot-(dpil+2*tgp1)))' $ relative to CdotM
.PARAM CgOuter = '1e-3 * 2*pi*eps0*epsBarr*hox/log(1+2*tgp2/dpil)' $ relative to CgInner
.PARAM Cg = 'CgInner/(1/CdotM+1/CgOuter)'
.PARAM Cd = '0.5*(CdotM-Cg)'

* Energies relative to conduction band minimum [eV], dimensionless factors to account for perpendicular degeneracy
.PARAM _E0 = '0.5/(ec0*mDot*me0)*(hbar0*pi/ddot)**2'
.PARAM _E0finite = '_E0**2/(4*Ebarr)*(SQRT(4*Ebarr/_E0+1)-1)**2'
.PARAM _EnergyLevel(nx,ny,nz) = 'cen*_E0finite*(nx**2+ny**2+nz**2)'
.PARAM _WFFactor(nx,ny,nz) = '((nx!=ny)+1)/(nx**2*ny**2)'

* List of energy levels
.PARAM En0	= '_EnergyLevel(1,1,1)'
.PARAM Wf0	= '_WFFactor(1,1,1)'
.PARAM En1	= '_EnergyLevel(1,1,2)'
.PARAM Wf1	= '_WFFactor(1,1,2)'
.PARAM En2	= '_EnergyLevel(1,1,3)'
.PARAM Wf2	= '_WFFactor(1,1,3)'
.PARAM En3	= '_EnergyLevel(1,3,1)'
.PARAM Wf3	= '_WFFactor(1,3,1)'
.PARAM En4	= '_EnergyLevel(1,3,2)'
.PARAM Wf4	= '_WFFactor(1,3,2)'

* Energy terms [eV^2.5]
.PARAM _En(En,Edot,Efermi,fdSign) = '(En+Edot>0)*En*(En+Edot)**1.5/(EXP(beta*fdSign*(En+Edot-Efermi))+1)'

* Sum of energy terms [eV^2.5]
.PARAM _sumEnElecDot(N,Edot,Efermi) =  '\
	Wf0 * _En(En0,Edot,Efermi,1) * (gDot-min(N,gDot)) + \
	Wf1 * _En(En1,Edot,Efermi,1) * gDot + \
	Wf2 * _En(En2,Edot,Efermi,1) * gDot + \
	Wf3 * _En(En3,Edot,Efermi,1) * gDot + \
	Wf4 * _En(En4,Edot,Efermi,1) * gDot'

.PARAM _sumEnDotElec(N,Edot,Efermi) =  '\
	Wf0 * _En(En0,Edot,Efermi,-1) * N'

* Rate prefactors
.PARAM _pfSrc	= '1e15 * ddot * SQRT(mElec*me0*ec0)*ec0*mBarr*gElec/(mDot*Ebarr*hbar0**2) \
	* EXP(-2*SQRT(2*mBarr*me0*ec0*Ebarr)/hbar0*dSrc)'
.PARAM _pfDrn	= '1e15 * ddot * SQRT(mElec*me0*ec0)*ec0*mBarr*gElec/(mDot*Ebarr*hbar0**2) \
	* EXP(-2*SQRT(2*mBarr*me0*ec0*Ebarr)/hbar0*dDrn)'

* Energy shift of quantum dot conduction band minimum due to charge state and applied bias voltages
.PARAM _Edot(Ndot,Vg,Vd) = '0.1*ec0*((Ndot>0)/Cdot0+(Ndot>1)*(Ndot-1)/Cdot1 - Qbg/Cdot1) - Vg*Cg/Cdot1 - Vd*Cd/Cdot1'

* Minimum charge state to be considered at operation point (Vg,Vd)
.PARAM _sepshift = 0.0   $ shift the boundary between charge states in order to adjust stitching
.PARAM _Qdot(Vg,Vd) = 'Qbg + 1 - Cdot1/Cdot0 + ( Cg*Vg - (Cdot1-Cd)*Vd - Cdot1*En0 )*10/ec0' $ [e]
.PARAM _NdotMin(Vg,Vd) = 'max(0, nint(_sepshift + _Qdot(Vg,Vd)))'

* Tunneling rates
.PARAM _rSrcDot(Ndot,Vg,Vd) = '_pfSrc * _sumEnElecDot(Ndot, _Edot(Ndot,Vg,Vd), EfSrc)'
.PARAM _rDotSrc(Ndot,Vg,Vd) = '_pfSrc * _sumEnDotElec(Ndot, _Edot(Ndot-1,Vg,Vd), EfSrc)'
.PARAM _rDrnDot(Ndot,Vg,Vd) = '_pfDrn * _sumEnElecDot(Ndot, _Edot(Ndot,Vg,Vd) + Vd, EfDrn)'
.PARAM _rDotDrn(Ndot,Vg,Vd) = '_pfDrn * _sumEnDotElec(Ndot, _Edot(Ndot-1,Vg,Vd) + Vd, EfDrn)'

* Tunneling current
.PARAM _currnum(Ndot,Vg,Vd) = '( \
	((_rDotDrn(Ndot+2,Vg,Vd)+_rDotSrc(Ndot+2,Vg,Vd)) * (_rDotDrn(Ndot+3,Vg,Vd)+_rDotSrc(Ndot+3,Vg,Vd)) \
	*(_rSrcDot(Ndot+0,Vg,Vd)*_rDotDrn(Ndot+1,Vg,Vd)  -  _rDotSrc(Ndot+1,Vg,Vd)*_rDrnDot(Ndot+0,Vg,Vd)) \
	+(_rSrcDot(Ndot+0,Vg,Vd)+_rDrnDot(Ndot+0,Vg,Vd)) * (_rDotDrn(Ndot+3,Vg,Vd)+_rDotSrc(Ndot+3,Vg,Vd)) \
	*(_rSrcDot(Ndot+1,Vg,Vd)*_rDotDrn(Ndot+2,Vg,Vd)  -  _rDotSrc(Ndot+2,Vg,Vd)*_rDrnDot(Ndot+1,Vg,Vd)) \
	+(_rSrcDot(Ndot+0,Vg,Vd)+_rDrnDot(Ndot+0,Vg,Vd)) * (_rSrcDot(Ndot+1,Vg,Vd)+_rDrnDot(Ndot+1,Vg,Vd)) \
	*(_rSrcDot(Ndot+2,Vg,Vd)*_rDotDrn(Ndot+3,Vg,Vd)  -  _rDotSrc(Ndot+3,Vg,Vd)*_rDrnDot(Ndot+2,Vg,Vd)))\
	)'
.PARAM _currdenom(Ndot,Vg,Vd) = '( \
	((_rSrcDot(Ndot+0,Vg,Vd)+_rDrnDot(Ndot+0,Vg,Vd)) * ((_rSrcDot(Ndot+1,Vg,Vd)+_rDrnDot(Ndot+1,Vg,Vd)) \
	*(_rSrcDot(Ndot+2,Vg,Vd)+_rDrnDot(Ndot+2,Vg,Vd)  +   _rDotDrn(Ndot+3,Vg,Vd)+_rDotSrc(Ndot+3,Vg,Vd)) \
	+(_rDotDrn(Ndot+2,Vg,Vd)+_rDotSrc(Ndot+2,Vg,Vd)) *  (_rDotDrn(Ndot+3,Vg,Vd)+_rDotSrc(Ndot+3,Vg,Vd)))\
	+(_rDotDrn(Ndot+1,Vg,Vd)+_rDotSrc(Ndot+1,Vg,Vd)) *  (_rDotDrn(Ndot+2,Vg,Vd)+_rDotSrc(Ndot+2,Vg,Vd)) \
	*(_rDotDrn(Ndot+3,Vg,Vd)+_rDotSrc(Ndot+3,Vg,Vd))) \
	)'
	
* ----- EQUIVALENT CIRCUIT ----- *

G1 1 3 CUR = '_currOff * 1e-19*ec0 * _currnum(_NdotMin(V(2,3)+VgOff,V(1,3)+VdOff),V(2,3)+VgOff,V(1,3)+VdOff) \
	/_currdenom(_NdotMin(V(2,3)+VgOff,V(1,3)+VdOff),V(2,3)+VgOff,V(1,3)+VdOff)'
R1 2 3 1e99
Rqd qd 3 1e99
Cgq 2 qd C='Cg*1e-18'
Cdq 1 qd C='Cd*1e-18'
Csq 3 qd C='Cd*1e-18'
Cgd 2 1 C='1e-21 * pi*eps0*epsBarr*(0.5*hg+tgp)/log(1+2*tgp/dpil)'
Cgs 2 3 C='1e-21 * pi*eps0*epsBarr*(0.5*hg+tgp)/log(1+2*tgp/dpil)'
Cds 1 3 C='1e-21 * pi*eps0*epsBarr*(0.25*dpil**2-0.25*ddot**2)/hox'


.ENDS


